@@ -235,7 +235,7 @@ def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = T
         TEMP = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
     else: TEMP = tempdir
 
-    options += " temp=" + TEMP + " n=" + str(len(os.path.split(scons))-1)   
+    options += " temp=" + TEMP + " n=" + str(len(os.path.split(scons)))   
     cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
     cleancmd = cmd + " --clean"
     
